@@ -36,14 +36,17 @@ PdfDocumentProcessor::~PdfDocumentProcessor() = default;
 
 bool PdfDocumentProcessor::canHandleData(const QByteArray &encodedData, QStringView fileName) const
 {
-    return PdfDocument::maybePdf(encodedData) || fileName.endsWith(QLatin1String(".pdf"), Qt::CaseInsensitive);
+  return PdfDocument::maybePdf(encodedData) ||
+         fileName.endsWith(QLatin1StringView(".pdf"), Qt::CaseInsensitive);
 }
 
 static void applyContextDateTime(PdfDocument *pdf, ExtractorDocumentNode &node)
 {
     // ignore broken PDF times for Amadeus documents
-    if (pdf->producer() == QLatin1String("Amadeus") && pdf->creationTime() == pdf->modificationTime() && pdf->creationTime().date().year() <= 2013) {
-        return;
+    if (pdf->producer() == QLatin1StringView("Amadeus") &&
+        pdf->creationTime() == pdf->modificationTime() &&
+        pdf->creationTime().date().year() <= 2013) {
+      return;
     }
 
     auto dt = pdf->modificationTime();
@@ -130,8 +133,14 @@ void PdfDocumentProcessor::expandNode(ExtractorDocumentNode &node, const Extract
             }
         }
 
-        // handle full page raster images
-        if ((engine->hints() & ExtractorEngine::ExtractFullPageRasterImages) && page.imageCount() == 1 && page.text().isEmpty()) {
+        // handle full page raster images (ignoring masks)
+        int imageCount = 0;
+        for (auto i = 0; i < page.imageCount(); ++i) {
+            if (page.image(i).type() == PdfImageType::Image) {
+                ++imageCount;
+            }
+        }
+        if ((engine->hints() & ExtractorEngine::ExtractFullPageRasterImages) && imageCount == 1 && page.text().isEmpty()) {
             qDebug() << "full page raster image";
             auto img = page.image(0);
             if (img.hasObjectId() &&  m_imageIds.find(img.objectId()) != m_imageIds.end()) { // already handled
