@@ -365,6 +365,25 @@ function parseEvent(event) {
     return res;
 }
 
+function parseReservationEvent(event) {
+    let res = JsonLd.newTrainReservation();
+    const names = event.summary.match(/(.*) ➞ (.*)/);
+    res.reservationFor.departureStation.name = names[1];
+    res.reservationFor.departureTime = JsonLd.readQDateTime(event, 'dtStart');
+    res.reservationFor.arrivalStation.name = names[2];
+    res.reservationFor.arrivalTime = JsonLd.readQDateTime(event, 'dtEnd');
+
+    const trip = event.description.match(/.* ➞ .*\n\[.*: \d .* (\S+), .* (\d+)\]\n(.*) \(.*\n.* ab .* ▷ \S+ (\S.*)\n.* an ?.* ▷ \S+ (\S.*)\n/);
+    res.reservationFor.departurePlatform = trip[4];
+    res.reservationFor.trainName = trip[3];
+    res.reservationFor.arrivalPlatform = trip[5];
+    res.reservedTicket.ticketedSeat.seatSection = trip[1];
+    res.reservedTicket.ticketedSeat.seatNumber = trip[2];
+
+    return res;
+}
+
+// various create DB Regio ERA TLB in PLAI format...
 function parseDBRegioBusUic(uic, node)
 {
     let ticket = node.result[0];
@@ -390,3 +409,24 @@ function parseDBRegioBusUic(uic, node)
     }
     return ticket;
 }
+
+function parseDBRegioNVUic(uic, node)
+{
+    let ticket = node.result[0];
+    if (uic.ticketLayout.type != 'PLAI' || ticket.name)
+        return;
+
+    const text = uic.ticketLayout.text(1, 1, 33, 12);
+    const data = text.match(/(.*) (\d).Kl\nVon (\d{2}\.\d{2}\.\d{4} \d{2}:\d{2})\nBis (\d{2}\.\d{2}\.\d{4} \d{2}:\d{2})\nVon (.*) \(.*\)\nNach (.*) \(.*\)\n/);
+    ticket.name = data[1];
+    ticket.ticketedSeat = { "@type": "Seat", seatingType: data[2] };
+    ticket.validFrom = JsonLd.toDateTime(data[3], "dd.MM.yyyy hh:mm", "de");
+    ticket.validUntil = JsonLd.toDateTime(data[4], "dd.MM.yyyy hh:mm", "de");
+
+    let res = JsonLd.newTrainReservation();
+    res.reservedTicket = ticket;
+    res.reservationFor.departureStation.name = data[5];
+    res.reservationFor.departureTime = ticket.validFrom;
+    res.reservationFor.arrivalStation.name = data[6];
+    return res;
+}
